@@ -1,9 +1,8 @@
 //! Google Cloud Platform structured logging using JSON, following
 //! <https://cloud.google.com/logging/docs/structured-logging>.
 
-use std::fmt;
+use std::fmt::{self, Write};
 use std::io::IoSlice;
-use std::io::Write;
 
 use log::{kv, Record};
 
@@ -114,12 +113,12 @@ fn severity(level: log::Level) -> &'static [u8] {
 fn write_msg(buf: &mut Buffer, args: &fmt::Arguments) {
     buf.buf.truncate(TS_END_INDEX);
     #[cfg(not(feature = "nightly"))]
-    write!(buf.buf, "{}", args).unwrap_or_else(|_| unreachable!());
+    write!(JsonBuf(&mut buf.buf), "{}", args).unwrap_or_else(|_| unreachable!());
     #[cfg(feature = "nightly")]
     if let Some(msg) = args.as_str() {
-        buf.buf.extend_from_slice(msg.as_bytes());
+        JsonBuf(&mut buf.buf).extend_from_slice(msg.as_bytes());
     } else {
-        write!(buf.buf, "{}", args).unwrap_or_else(|_| unreachable!());
+        write!(JsonBuf(&mut buf.buf), "{}", args).unwrap_or_else(|_| unreachable!());
     }
     buf.indices[0] = buf.buf.len();
 }
@@ -202,6 +201,16 @@ impl<'b, 'kvs> kv::Visitor<'kvs> for KeyValueVisitor<'b> {
 /// [`fmt::Write`] implementation that writes escaped strings.
 struct JsonBuf<'b>(&'b mut Vec<u8>);
 
+impl<'b> JsonBuf<'b> {
+    #[cfg(feature = "nightly")]
+    fn extend_from_slice(&mut self, bytes: &[u8]) {
+        for b in bytes {
+            self.write_char(*b as char)
+                .unwrap_or_else(|_| unreachable!());
+        }
+    }
+}
+
 impl<'b> fmt::Write for JsonBuf<'b> {
     #[inline]
     fn write_str(&mut self, string: &str) -> fmt::Result {
